@@ -1,8 +1,7 @@
-from datetime import datetime
 from typing import Dict
 
 from bolinette import types, blnt, core
-from bolinette.exceptions import InternalError, ParamMissingError, EntityNotFoundError
+from bolinette.exceptions import InternalError
 
 
 class Mapping:
@@ -79,46 +78,3 @@ class Mapping:
                 values[field.name] = self.marshall(d, getattr(entity, field.name), skip_none=skip_none,
                                                    as_list=True, use_foreign_key=use_foreign_key)
         return values
-
-    async def link_foreign_entities(self, definition, params):
-        errors = []
-        for field in definition.fields:
-            if isinstance(field, types.mapping.Reference):
-                value = params.get(field.foreign_key, None)
-                repo: blnt.Repository = self.context.repo(field.reference_model)
-                if value is not None and repo is not None:
-                    entity = await repo.get_first_by(field.reference_key, value)
-                    if entity is None:
-                        errors.append((field.reference_model, field.reference_key, value))
-        if len(errors) > 0:
-            raise EntityNotFoundError(params=errors)
-
-    def validate_payload(self, definition, params, patch=False):
-        errors = []
-        valid = {}
-        for field in definition.fields:
-            if isinstance(field, types.mapping.Reference):
-                if patch and field.foreign_key not in params:
-                    continue
-                link = params.get(field.foreign_key)
-                if not link or not len(str(link)):
-                    if field.required:
-                        errors.append(field.foreign_key)
-                    else:
-                        link = field.default
-                valid[field.foreign_key] = link
-            if isinstance(field, types.mapping.Field):
-                if patch and field.name not in params:
-                    continue
-                value = params.get(field.name, None)
-                if value and field.type == types.db.Date:
-                    value = datetime.strptime(value, '%Y-%m-%dT%H:%M:%S')
-                if not value or not len(str(value)):
-                    if field.required:
-                        errors.append(field.name)
-                    else:
-                        value = field.default
-                valid[field.name] = value
-        if len(errors) > 0:
-            raise ParamMissingError(params=errors)
-        return valid
