@@ -1,7 +1,6 @@
 from bolinette import blnt
 from bolinette.decorators import controller, get
 from bolinette.defaults.services import TimezoneService
-from bolinette.utils import response
 
 
 @controller('tz', '/tz')
@@ -12,4 +11,4 @@ class TimezoneController(blnt.Controller):
 
     @get('')
     async def all_timezones(self):
-        return response.ok('OK', await self.tz_service.get_all())
+        return self.response.ok('OK', await self.tz_service.get_all())
