@@ -1,9 +1,9 @@
-from bolinette import types, data
+from bolinette import types, blnt
 from bolinette.decorators import model
 
 
 @model('role')
-class Role(data.Model):
+class Role(blnt.Model):
     id = types.defs.Column(types.db.Integer, primary_key=True)
     name = types.defs.Column(types.db.String, unique=True, nullable=False)
 
