@@ -1,6 +1,6 @@
-from bolinette_common import logger
+from bolinette.utils import logger
 
-from bolinette import env
+from bolinette import core
 from bolinette.mail.providers import Mailgun
 
 _providers = {
@@ -9,18 +9,19 @@ _providers = {
 
 
 class Sender:
-    def __init__(self):
+    def __init__(self, context: 'core.BolinetteContext'):
+        self.context = context
         self.provider = None
 
     def init_app(self):
-        provider = env['MAIL_PROVIDER']
+        provider = self.context.env['MAIL_PROVIDER']
         if provider:
             provider = provider.lower()
             if provider not in _providers:
                 logger.warning(f'Unknown "{provider}" mail provider. '
                                f'Available: {", ".join(_providers.keys())}')
             else:
-                self.provider = _providers[provider]()
+                self.provider = _providers[provider](self.context)
 
     async def send(self, to, subject, content):
         if self.provider:
@@ -28,6 +29,3 @@ class Sender:
                 self.provider.send(to, subject, content)
             except Exception as ex:
                 logger.error(str(ex))
-
-
-sender = Sender()
